Errors that can occur during NVS operations. The list is likely to stay as is but marked as
non-exhaustive to allow for future additions without breaking the API. A caller would likely only
need to handle NamespaceNotFound and KeyNotFound as the other errors are static.