pub struct Key(/* private fields */);Expand description
A 16-byte key used for NVS storage (15 characters + null terminator)
Implementations
Sourceimpl Key
impl Key
Sourcepub const fn from_array<const M: usize>(src: &[u8; M]) -> Self
pub const fn from_array<const M: usize>(src: &[u8; M]) -> Self
Creates a 16 byte, null-padded byte array used as key for values and namespaces.
Usage: Key::from_array(b"my_key")
Tip: use a const context if possible to ensure that the key is transformed at compile time:
let my_key = const { Key::from_array(b"my_key") };
Sourcepub const fn from_slice(src: &[u8]) -> Self
pub const fn from_slice(src: &[u8]) -> Self
Creates a 16 byte, null-padded byte array used as key for values and namespaces.
Usage: Key::from_slice(b"my_key")
Tip: use a const context if possible to ensure that the key is transformed at compile time:
let my_key = const { Key::from_slice("my_key".as_bytes()) };