Nvs

Struct Nvs 

pub struct Nvs<'a, T>
where T: Platform,
{ /* private fields */ }
The Nvs struct keeps information about all pages in memory. Increases in size with the numer of pages in the partition.

Implementations

Source

impl<'a, T> Nvs<'a, T>
where T: Platform,

pub fn new( partition_offset: usize, partition_size: usize, hal: &'a mut T, ) -> Result<Nvs<'a, T>, Error>

Mimics the original C++ driver behavior and reads all sectors of the given partition to

  1. Resolve all existing namespaces
  2. Create a hashed key cache per page for quicker lookups
  3. Cleanup duplicate entries
  4. Cleanup of duplicated blobs or orphaned blob data

Pages or entries with invalid CRC32 values are marked as corrupt and are erased when necessary

pub fn get<R>(&mut self, namespace: &Key, key: &Key) -> Result<R, Error>
where Nvs<'a, T>: Get<R>,

Get a value from the flash.

Supported types are bool, singed and unsigned integers up to 64-bit width, String and Vec.

Both namespace and may have up to 15 characters.

pub fn set<R>( &mut self, namespace: &Key, key: &Key, value: R, ) -> Result<(), Error>
where Nvs<'a, T>: Set<R>,

Set a value and write it to the flash

Type support:

  • bool, singed and unsigned integers up to 64-bit width: saved as primitive value with 32 bytes
  • &str: Saved on a single page with a max size of 4000 bytes
  • &u8: May span multiple pages, max size ~500kB
pub fn delete(&mut self, namespace: &Key, key: &Key) -> Result<(), Error>

Delete a key

Ignores missing keys or the namespaces

pub fn statistics(&mut self) -> Result<NvsStatistics, Error>

Returns detailed statistics about the NVS partition usage